@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py,v 1.55 2006/10/13 23:39:04 wwalker Exp $"
-__version__   = "$Revision: 1.55 $"
-__date__      = "$Date: 2006/10/13 23:39:04 $"
+__id__        = "$Id: gnomespeechfactory.py 1945 2007-01-19 21:32:18Z wwalker $"
+__version__   = "$Revision: 1945 $"
+__date__      = "$Date: 2007-01-19 16:32:18 -0500 (Fri, 19 Jan 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -41,10 +41,12 @@ import bonobo
 import atspi
 import chnames
 import debug
+import orca_state
 import punctuation_settings
 import settings
 import speech
 import speechserver
+import util
 
 from acss import ACSS
 
@@ -361,7 +363,50 @@ class SpeechServer(speechserver.SpeechServer):
         if self.__speakers.has_key(acss.name()):
             return self.__speakers[acss.name()]
 
-        # Create a new voice for all unique ACSS's we see.
+        # Search for matching languages first, as that is the most
+        # important thing.  We also try to look for the desired language
+        # first, but then fall back to the default language.
+        #
+        languages = []
+        try:
+            if acss.has_key(ACSS.FAMILY):
+                family = acss[ACSS.FAMILY]
+                languages = [family[speechserver.VoiceFamily.LOCALE]]
+            elif defaultACSS.has_key(ACSS.FAMILY):
+                family = defaultACSS[ACSS.FAMILY]
+                languages = [family[speechserver.VoiceFamily.LOCALE]]
+        except:
+            pass
+
+        # [[[TODO: WDW - I'm using an array of languages here because
+        # it will give us the opportunity to provide a match for
+        # gnome-speech driver implementations that do not designate
+        # languages using the combination of ISO 639-1 and 3166-1
+        # language_region strings (e.g., they use 'english' instead of
+        # "en_US").  Thus, we could detect the default language is
+        # "en_US" and just automatically append "english" and such to
+        # the list to allow us to accomodate these kind of
+        # variants.]]]
+        #
+        if len(languages) == 0:
+            import locale
+            language, encoding = locale.getdefaultlocale()
+            languages = [language]
+
+        voices = self.__driver.getAllVoices()
+        foundVoices = []
+        for voice in voices:
+            if voice.language in languages:
+                foundVoices.append(voice)
+
+        # If we didn't find any matches, well...punt.
+        #
+        if len(foundVoices):
+            voices = foundVoices
+        else:
+            voices = self.__driver.getAllVoices()
+
+        # Now search for a matching family name.
         #
         familyName = None
         if acss.has_key(ACSS.FAMILY):
@@ -371,7 +416,6 @@ class SpeechServer(speechserver.SpeechServer):
             family = defaultACSS[ACSS.FAMILY]
             familyName = family[speechserver.VoiceFamily.NAME]
 
-        voices = self.__driver.getAllVoices()
         found = False
         for voice in voices:
             if (not familyName) or (voice.name == familyName):
@@ -616,6 +660,19 @@ class SpeechServer(speechserver.SpeechServer):
         oldText = oldText.replace("\342\200\246",  _(" dot dot dot"), 1)
         oldText = oldText.decode("UTF-8")
 
+        ## Don't speak newlines unless the user is moving through text
+        ## using a right or left arrow key.
+        ##
+        removeNewLines = True
+        if orca_state.lastInputEvent and \
+               orca_state.lastInputEvent.__dict__.has_key("event_string"):
+            lastKey = orca_state.lastInputEvent.event_string
+            if lastKey == "Left" or lastKey == "Right":
+                removeNewLines = False
+
+        if removeNewLines:
+            oldText = oldText.replace("\n", "", 1)
+
         style = settings.verbalizePunctuationStyle
         newText = ''
         for i in range(0, len(oldText)):
@@ -636,7 +693,26 @@ class SpeechServer(speechserver.SpeechServer):
                 #
                 isSpecial = isPrev and isNext and (oldText[i] == ".")
 
-                if (len(oldText) == 1) or isSpecial or (style <= level):
+                # If this is a dash and the users punctuation level is not
+                # NONE and the previous character is a white space character,
+                # and the next character is a dollar sign or a digit, then
+                # always speak it. See bug #392939.
+                #
+                prevCharMatches = nextCharMatches = False
+                currencySymbols = util.getUnicodeCurrencySymbols()
+                if i > 0:
+                    prevCharMatches = (oldText[i - 1] in string.whitespace)
+                if i < (len(oldText) - 1):
+                    nextCharMatches = (oldText[i + 1] in string.digits or \
+                                       oldText[i + 1] in currencySymbols)
+
+                if oldText[i] == "-" and \
+                   style != settings.PUNCTUATION_STYLE_NONE and \
+                   prevCharMatches and nextCharMatches:
+                    if isPrev:
+                        newText += " "
+                    newText += _("minus")
+                elif (len(oldText) == 1) or isSpecial or (style <= level):
                     if isPrev:
                         newText += " "
                     newText += chnames.getCharacterName(oldText[i])
@@ -691,6 +767,7 @@ class SpeechServer(speechserver.SpeechServer):
             return -1
 
         text = self.__addVerbalizedPunctuation(text)
+        text = util.adjustForPronunciation(text)
 
         try:
             # [[[TODO: WDW - back this stop out for now.  The problem is
