@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,10 +20,10 @@
 """Manages the magnifier for orca.  [[[TODO: WDW - this is very very
 early in development.  One might even say it is pre-prototype.]]]"""
 
-__id__        = "$Id: mag.py 1452 2006-09-19 21:30:55Z richb $"
-__version__   = "$Revision: 1452 $"
-__date__      = "$Date: 2006-09-19 17:30:55 -0400 (Tue, 19 Sep 2006) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: mag.py 2076 2007-03-02 23:01:44Z wwalker $"
+__version__   = "$Revision: 2076 $"
+__date__      = "$Date: 2007-03-02 18:01:44 -0500 (Fri, 02 Mar 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import bonobo
@@ -253,6 +253,11 @@ def __dumpPropertyBag(obj):
     slots = pbag.getKeys("")
     print "  Available slots: ", pbag.getKeys("")
     for slot in slots:
+        # These crash the magnifier since it doesn't know how to marshall
+        # them to us.
+        #
+        if slot in ["cursor-set", "smoothing-type"]:
+            continue
         print "    About '%s':" % slot
         print "    Doc Title:", pbag.getDocTitle(slot)
         print "    Type:", pbag.getType(slot)
@@ -427,12 +432,14 @@ def applySettings():
     _maxROIX = _sourceDisplayBounds.x2 - (_roiWidth / 2)
     _maxROIY = _sourceDisplayBounds.y2 - (_roiHeight / 2)
 
+    _magnifier.addZoomRegion(_zoomer)
+
     #print "MAGNIFIER PROPERTIES:", _magnifier
     #__dumpPropertyBag(_magnifier)
     #print "ZOOMER PROPERTIES:", _zoomer
     #__dumpPropertyBag(_zoomer)
 
-def magnifyAccessible(event, obj):
+def magnifyAccessible(event, obj, extents=None):
     """Sets the region of interest to the upper left of the given
     accessible, if it implements the Component interface.  Otherwise,
     does nothing.
@@ -445,7 +452,9 @@ def magnifyAccessible(event, obj):
     if not _initialized:
         return
 
-    if event and (event.type == "object:text-caret-moved") \
+    if extents:
+        [x, y, width, height] = extents
+    elif event and (event.type == "object:text-caret-moved") \
        and obj.text and (obj.text.caretOffset >= 0):
         offset = obj.text.caretOffset
         [x, y, width, height] = obj.text.getCharacterExtents(offset,
