@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 1720 2006-11-17 20:33:57Z wwalker $"
-__version__   = "$Revision: 1720 $"
-__date__      = "$Date: 2006-11-17 15:33:57 -0500 (Fri, 17 Nov 2006) $"
+__id__        = "$Id: orca_console_prefs.py 1945 2007-01-19 21:32:18Z wwalker $"
+__version__   = "$Revision: 1945 $"
+__date__      = "$Date: 2007-01-19 16:32:18 -0500 (Fri, 19 Jan 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -169,7 +169,8 @@ def setupSpeech(prefsDict):
         i = 1
         choices = {}
         for family in families:
-            name = family[speechserver.VoiceFamily.NAME]
+            name = family[speechserver.VoiceFamily.NAME] \
+                + " (%s)" %  family[speechserver.VoiceFamily.LOCALE]
             voice = acss.ACSS({acss.ACSS.FAMILY : family})
             sayAndPrint(_("%d. %s") % (i, name),
                         False,              # stop
