@@ -33,9 +33,9 @@ created in their own module.  The module defining the Script subclass
 is also required to have a 'getScript(app)' method that returns an
 instance of the Script subclass.  See default.py for an example."""
 
-__id__        = "$Id: script.py,v 1.41 2006/11/30 16:38:58 richb Exp $"
-__version__   = "$Revision: 1.41 $"
-__date__      = "$Date: 2006/11/30 16:38:58 $"
+__id__        = "$Id: script.py 1996 2007-02-11 18:07:28Z joanied $"
+__version__   = "$Revision: 1996 $"
+__date__      = "$Date: 2007-02-11 13:07:28 -0500 (Sun, 11 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -88,6 +88,15 @@ class Script:
 
         self.findCommandRun = False
 
+        # Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
+        # always mean an object disappeared - there just might be a network
+        # glitch.  So, on COMM_FAILURES, we might retry a few times before
+        # giving up on an object.  This might need to be overridden by the
+        # script.  See bug #397787.
+        #
+        self.commFailureWaitTime = 0.1
+        self.commFailureAttemptLimit = 5
+
         debug.println(debug.LEVEL_FINE, "NEW SCRIPT: %s" % self.name)
 
     def getListeners(self):
